<?php

declare(strict_types=1);

namespace Drupal\locale_download\Commands;

use Drupal\locale_download\Service\LocaleDownloadService;
use Drush\Commands\DrushCommands;

/**
 * Drush commands for locale_download module.
 */
class LocaleDownloadCommands extends DrushCommands {

  /**
   * Construct new instance.
   *
   * @param \Drupal\locale_download\Service\LocaleDownloadService $downloader
   *   The download service.
   */
  public function __construct(
    protected LocaleDownloadService $downloader,
  ) {}

  /**
   * Downloads all translation files from remote to local.
   *
   * @command locale:download
   * @option projects Comma separated list of projects (modules) to download. Defaults to all projects.
   * @option langcodes Comma separated list of language codes to download. Defaults to all locales.
   * @option force Clears static cache before downloading.
   */
  public function download($options = [
    'projects' => NULL,
    'langcodes' => NULL,
    'force' => FALSE,
  ]): void {
    if ($projects = $options['projects']) {
      $projects = is_string($projects) ? explode(',', $projects) : NULL;
    }

    if ($langcodes = $options['langcodes']) {
      $langcodes = is_string($langcodes) ? explode(',', $langcodes) : NULL;
    }

    $this->downloader->download(
      $projects,
      $langcodes,
      $options['force'],
    );
  }

}
